@@ -1,6 +1,6 @@
 from ._cftime import (datetime, real_datetime,
-                      _parse_date, _dateparse, _datesplit)
-from ._cftime import num2date, date2num, date2index, time2index, num2pydate
+                      _parse_date, _dateparse, _datesplit, is_leap_year)
+from ._cftime import num2date, date2num, date2index, time2index, num2pydate, to_tuple
 from ._cftime import (microsec_units, millisec_units,
                      sec_units, hr_units, day_units, min_units,
                      UNIT_CONVERSION_FACTORS)
